package com.altimetrik.articles.controllers;

import java.util.Set;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.CrossOrigin;
import com.altimetrik.articles.entity.Article;
import com.altimetrik.articles.util.ArticlesUtil;
import java.util.ArrayList;
import java.util.List;


import lombok.extern.slf4j.Slf4j;

@CrossOrigin
@Controller
@RequestMapping("/articles")
@Slf4j
public class ArticleController {
	@Autowired
	ArticlesUtil articleUtil;

	@GetMapping(value = "/", produces = MediaType.APPLICATION_JSON_VALUE, consumes = MediaType.ALL_VALUE)
	public ResponseEntity<List<Article>> getALL() {
		log.info("Inside get all method");
		return new ResponseEntity(articleUtil.call(), HttpStatus.OK);
	}

	@GetMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE, consumes = MediaType.ALL_VALUE)
	public ResponseEntity<List<Article>> getById(@PathVariable("id") Integer id) {
		log.info("Inside getbyId method");

		return new ResponseEntity(articleUtil.call(id), HttpStatus.OK);
	}

	@PostMapping(value = "/", produces = MediaType.APPLICATION_JSON_VALUE, consumes = MediaType.ALL_VALUE)
	public ResponseEntity<Article> createArticle(@RequestBody Article article) {
		log.info("Inside creat method");
		return new ResponseEntity(articleUtil.create(article), HttpStatus.OK);
	}

	@PutMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE, consumes = MediaType.ALL_VALUE)
	public ResponseEntity<Article> updateArticle(@PathVariable("id") Integer id) {
		log.info("Inside update method");
		try {
			return new ResponseEntity(articleUtil.update(id), HttpStatus.OK);
		}
		catch (Exception e) {
			log.error("Error while update : {}", e.getMessage());
		}
		return new ResponseEntity(null, HttpStatus.EXPECTATION_FAILED);
	}
}
